/* src/bazaar.p/bz-curated-row.h
 *
 * Copyright 2026 AUTOGEN
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <glib-object.h>
#include "bz-curated-section.h"
#include "bz-curated-featured-carousel.h"
#include "bz-curated-banner.h"
#include "bz-curated-articles-info.h"

G_BEGIN_DECLS



#define BZ_TYPE_CURATED_ROW (bz_curated_row_get_type ())
G_DECLARE_FINAL_TYPE (BzCuratedRow, bz_curated_row, BZ, CURATED_ROW, GObject)

BzCuratedRow *
bz_curated_row_new (void);

BzCuratedSection *
bz_curated_row_get_section (BzCuratedRow *self);

BzCuratedFeaturedCarousel *
bz_curated_row_get_featured_carousel (BzCuratedRow *self);

BzCuratedBanner *
bz_curated_row_get_banner (BzCuratedRow *self);

BzCuratedArticlesInfo *
bz_curated_row_get_articles (BzCuratedRow *self);

void
bz_curated_row_set_section (BzCuratedRow *self,
    BzCuratedSection *section);

void
bz_curated_row_set_featured_carousel (BzCuratedRow *self,
    BzCuratedFeaturedCarousel *featured_carousel);

void
bz_curated_row_set_banner (BzCuratedRow *self,
    BzCuratedBanner *banner);

void
bz_curated_row_set_articles (BzCuratedRow *self,
    BzCuratedArticlesInfo *articles);



G_END_DECLS

/* End of src/bazaar.p/bz-curated-row.h */
